@@ -36,7 +36,7 @@ from PyQt5.Qt import (QSettings,
                       
 )
 
-from PyQt5.QtCore import QUrl, Qt, QSize, QLibraryInfo 
+from PyQt5.QtCore import QCoreApplication, QUrl, Qt, QSize, QLibraryInfo 
 from PyQt5.QtWebEngineWidgets import (QWebEngineView, QWebEngineSettings)
 from PyQt5 import uic, QtPrintSupport
 from PyQt5.QtGui import (QIcon,
@@ -47,6 +47,7 @@ from PyQt5.QtGui import (QIcon,
                        
 )
 from PyQt5.QtWidgets import (QFileDialog,
+                             
                              QApplication,
                              QTableWidgetItem,
                              QListWidgetItem,
@@ -58,7 +59,7 @@ from appdirs import AppDirs
 from helperScripts import parser240, parser321, parser331
 
 global VERSION 
-VERSION = '0.5.5'
+VERSION = '0.5.6'
 
 class StandardItem(QStandardItem):
     def __init__(self, txt='', id='root', font_size=15, set_bold=False, color=QColor(0, 0, 0)):
@@ -153,32 +154,8 @@ class UI(QMainWindow):
         self.iconFont=QFont('Material Icons')
         self.iconFont.setWeight(0)
         self.appFont=QFont('Ubuntu')
-        
-        if sys.platform=='darwin':
-            appFontSize=15
-            appFontWeight=QFont.Normal
-            buttonFontSize=17
-            iconFontSize=24
-             
-        else:
-            appFontSize=15
-            appFontWeight=QFont.Normal
-            buttonFontSize=17
-            iconFontSize=24
-
-        self.appFont.setPixelSize(appFontSize)
-        self.appFont.setWeight(appFontWeight)
-        self.setFont(self.appFont)
-        if app:
-            app.setFont(self.appFont)
-        
-        self.iconFont.setPixelSize(iconFontSize)
-        self.buttonFont.setPixelSize(buttonFontSize)
-        
-        self.deleteFavoriteButton.setFont(self.buttonFont)
-        self.filterMagic.setFont(self.buttonFont)
-        self.toolBar.setFont(self.iconFont)
-
+        self.__setFontsizes()
+       
         self.setWindowTitle('openXJV %s' % VERSION)
         
         #Hide "New version" icon
@@ -328,6 +305,7 @@ class UI(QMainWindow):
         self.browser.page().profile().downloadRequested.connect(self.__downloadRequested)
         self.browser.page().printRequested.connect(self.__printRequested)
         self.actionNeueVersion.triggered.connect(lambda triggered: QDesktopServices.openUrl(QUrl("https://openxjv.de" , QUrl.TolerantMode)))
+        self.actionGrosse_Schrift.triggered.connect(self.__updateSettings)
         for columnSetting in self.docHeaderColumnsSettings.values():
             if columnSetting['setting']:
                 columnSetting['setting'].triggered.connect(self.__updateSettings)
@@ -337,10 +315,7 @@ class UI(QMainWindow):
 
         # Defaultgröße setzen
         screen_resolution = app.desktop().screenGeometry()
-        self.resize(int(screen_resolution.width()/2),int(screen_resolution.height()/2))
-
-        # Maximiere Fenster
-        self.showMaximized()
+        self.resize(int(screen_resolution.width()/1.5),int(screen_resolution.height()/1.5))
         
         #Check for updates
         if self.actionOnlineAufUpdatesPruefen.isChecked():
@@ -546,10 +521,10 @@ class UI(QMainWindow):
                 headerText=self.docHeaderColumnsSettings[item]['headertext']
                 self.docTableView.setHorizontalHeaderItem(columnCount, self.__tableItem(headerText, self.appFont))
 
-                # set fixed width for items that have one defined...
+                # set width to auto for items that have a width defined (due to option to adjust font size width is ignored)...
                 if self.docHeaderColumnsSettings[item]['width']:
-                    self.docTableView.setColumnWidth(columnCount, self.docHeaderColumnsSettings[item]['width'])
-                    self.docTableView.horizontalHeader().setSectionResizeMode(columnCount, QHeaderView.Fixed)
+                    self.docTableView.horizontalHeader().setSectionResizeMode(columnCount, QHeaderView.ResizeToContents)
+            
                 columnCount+=1
                 
             rowNo=0
@@ -766,6 +741,60 @@ class UI(QMainWindow):
         
         self.__saveFavorites()    
     
+    def __setFontsizes(self, appFontsize=15, buttonFontSize=17, iconFontSize=24, appFontWeight=QFont.Normal):
+        '''Setzt die Schriftgröße für die Anwendung und Buttons'''
+        self.appFontsize = appFontsize
+        self.buttonFontSize = buttonFontSize
+        self.iconFontSize = iconFontSize
+        self.appFontWeight = appFontWeight
+        
+        self.iconFont.setPixelSize(iconFontSize)
+        self.buttonFont.setPixelSize(buttonFontSize)    
+        self.appFont.setPixelSize(appFontsize)
+        self.appFont.setWeight(appFontWeight)
+        self.setFont(self.appFont)
+        if self.app:
+            self.app.setFont(self.appFont)
+        
+        docTableRows       = self.docTableView.rowCount()
+        docTableColumns    = self.docTableView.columnCount()
+        
+        if docTableRows > 0 and docTableColumns > 0:
+            for column in range(docTableColumns):
+                    if column > 1:
+                        font=self.appFont
+                    else:
+                        font=self.buttonFont
+                    self.docTableView.horizontalHeaderItem(column).setFont(font)
+            for row in range(docTableRows):
+                for column in range(docTableColumns):
+                    if column > 1:
+                        font=self.appFont
+                    else:
+                        font=self.buttonFont
+                    self.docTableView.item(row, column).setFont(font)    
+          
+        termineTableRows    = self.termineTableView.rowCount()
+        termineTableColumns = self.termineTableView.columnCount()
+        
+        if termineTableRows > 0 and termineTableColumns > 0:
+            for column in range(termineTableColumns):
+                self.termineTableView.horizontalHeaderItem(column).setFont(self.appFont)
+            for row in range(termineTableRows):
+                for column in range(termineTableColumns):
+                    self.termineTableView.item(row, column).setFont(self.appFont)
+            
+        self.deleteFavoriteButton.setFont(self.buttonFont)
+        self.filterMagic.setFont(self.buttonFont)
+        self.toolBar.setFont(self.iconFont)
+
+    def __toggleFontsizes(self):
+        '''Toggle die Schriftgröße für die Anwendung und die Buttons'''
+        if self.actionGrosse_Schrift.isChecked():
+            self.__setFontsizes(appFontsize=20, buttonFontSize=20, iconFontSize=28)
+        else:
+            self.__setFontsizes()
+        
     def __removeFavorite(self):
         '''Entfernt den aktuell in der FavoritenView markierten Eintrag aus der Liste der Favoriten.'''
         if self.favoritenView.currentItem():
@@ -1002,6 +1031,7 @@ class UI(QMainWindow):
         self.settings.setValue('favoriten' , self.actionFavoriten.isChecked())
         self.settings.setValue('notizen' , self.actionNotizen.isChecked())
         self.settings.setValue('leereSpalten' , self.actionLeereSpaltenAusblenden.isChecked())
+        self.settings.setValue('grosseSchrift' , self.actionGrosse_Schrift.isChecked())
         
         if self.actionChromium.isChecked() and self.chromiumPdfViewerAvailable:
             self.settings.setValue('pdfViewer', 'chromium')
@@ -1014,7 +1044,7 @@ class UI(QMainWindow):
          
         self.__updateVisibleColumns()
         self.__updateVisibleViews()
-
+        self.__toggleFontsizes()
         
     def __viewerSwitch(self):
         '''Aktivert / deaktiviert die Viewerauswahl(-möglichkeiten) in Abhängigkeit vom ausgelösten Ereignis'''
@@ -1054,8 +1084,6 @@ class UI(QMainWindow):
             updateAvailable=self.__checkUrlforNewVersion('https://openXJV.de/latestAppImage.xml')
         elif sys.platform.lower().startswith('win'):
             updateAvailable=self.__checkUrlforNewVersion('https://openXJV.de/latestWinInstaller.xml')
-        elif sys.platform == 'darwin':
-            updateAvailable=self.__checkUrlforNewVersion('https://openXJV.de/latestMacApp.xml')
         else:
             self.actionOnlineAufUpdatesPruefen.setVisible(False)
         
@@ -1099,11 +1127,14 @@ class UI(QMainWindow):
         
         self.actionChromium.setChecked(True if self.settings.value('pdfViewer', 'PDFjs')=='chromium' and self.chromiumPdfViewerAvailable else False)
         self.actionnativ.setChecked(True if self.settings.value('pdfViewer', 'PDFjs')=='nativ' else False)     
+  
+        self.actionGrosse_Schrift.setChecked(True if str(self.settings.value('grosseSchrift', 'false')).lower()=='true' else False)
         
         self.actionOnlineAufUpdatesPruefen.setChecked(True if str(self.settings.value('checkUpdates', 'true')).lower()=='true' else False)
         
         self.__viewerSwitch()
         self.__updateVisibleViews()
+        self.__toggleFontsizes()
                 
     def __resetSettings(self):
         '''Setzt Spalten und Ansichtsoptionen auf Defaultwerte zurück'''
@@ -1820,7 +1851,9 @@ def launchApp():
     print('Disabling Chromium-Sandbox for compatibility reasons (Seems to be unavailable on Debian / Ubuntu based systems anyway).')
     os.environ["QTWEBENGINE_DISABLE_SANDBOX"] = "1"
     os.environ["QTWEBENGINE_CHROMIUM_FLAGS"]  = "--log-level=3"
-    
+    os.environ["QT_FONT_DPI"] = "96"
+    QCoreApplication.setAttribute(Qt.AA_DisableHighDpiScaling)
+
     app = QApplication([])
     app.setStyle('Fusion')
     app.setObjectName('openXJV')
@@ -1840,9 +1873,9 @@ def launchApp():
                 ziplist.append(file)
             
     widget = UI(file=file, ziplist=ziplist, app=app)
-    widget.setWindowFlags((widget.windowFlags() & ~Qt.WindowFullscreenButtonHint) | Qt.CustomizeWindowHint)
+    widget.setWindowFlags((widget.windowFlags() & ~Qt.WindowFullscreenButtonHint) | Qt.CustomizeWindowHint )
     app.aboutToQuit.connect(widget.cleanUp)
-    widget.show()
+    widget.showMaximized()
     sys.exit(app.exec_())
     
 if __name__ == "__main__":
